@@ -8,8 +8,8 @@ import os
 import sys
 import time
 
-startup_debug = os.environ.get("FastTracker_Debug", "off").lower() in ("on", "true", "1")
-fast_debug_level = int(os.environ.get("FastTracker_Debug_Level", "0"))
+startup_debug = os.environ.get("FastTracker.Debug", "off").lower() in ("on", "true", "1")
+fast_debug_level = int(os.environ.get("FastTracker.Debug.Level", "0"))
 
 
 def log_message(text, *args, level=1):
@@ -81,7 +81,7 @@ log_message("python_version_matches = %r", python_version_matches)
 
 if python_prefix_matches and python_version_matches:
 
-    config_file = os.environ.get("FastTracker_ConfigPath", None)
+    config_file = os.environ.get("FastTracker.ConfigPath", None)
     environment = os.environ.get("FAST_ENVIRONMENT", None)
 
     log_message("initialize_agent = %r", bool(config_file))
