@@ -95,57 +95,46 @@ class FastTrackerConfiger:
                         config.service_version_reader.clear()
                         config.set_service_version_reader(val_dict)
                     elif key.startswith("FastTracker.CarrierHeader."):
-                        args = {functions.lower_case_name(key[26:]): val}
+                        args = {key[26:]: val}
                         config.set_carrier_header(**args)
                     elif key.startswith("FastTracker.Logging."):
-                        args = {functions.lower_case_name(key[20:]): val}
+                        args = {key[20:]: val}
                         config.set_logging(**args)
                     elif key.startswith("FastTracker.Filter."):
-                        args = {functions.lower_case_name(key[19:]): val}
+                        args = {key[19:]: val}
                         config.set_logging(**args)
                     elif key.startswith("FastTracker.Transport."):
                         if key.startswith("FastTracker.Transport.Forward."):
-                            args = {functions.lower_case_name(key[30:]): val}
+                            args = {key[30:]: val}
                             config.set_forward(**args)
                         else:
-                            args = {functions.lower_case_name(key[22:]): val}
+                            args = {key[22:]: val}
                             config.set_transport(**args)
                     elif key.startswith("FastTracker.CollectLayer."):
                         if key.startswith("FastTracker.CollectLayer.HTTP."):
-                            args = {functions.lower_case_name(key[30:]): val}
+                            args = {key[30:]: val}
                             config.set_collectLayer_http(**args)
                         elif key.startswith("FastTracker.CollectLayer.DB."):
-                            args = {functions.lower_case_name(key[28:]): val}
+                            args = {key[28:]: val}
                             config.set_collectLayer_db(**args)
                         elif key.startswith("FastTracker.CollectLayer.MQ."):
-                            args = {functions.lower_case_name(key[28:]): val}
+                            args = {key[28:]: val}
                             config.set_collectLayer_mq(**args)
                         elif key.startswith("FastTracker.CollectLayer.Cache."):
-                            args = {functions.lower_case_name(key[31:]): val}
+                            args = {key[31:]: val}
                             config.set_collectLayer_cache(**args)
                         elif key.startswith("FastTracker.CollectLayer.Log."):
-                            args = {functions.lower_case_name(key[29:]): val}
+                            args = {key[29:]: val}
                             config.set_collectLayer_log(**args)
                         elif key.startswith("FastTracker.CollectLayer.Local."):
-                            args = {functions.lower_case_name(key[31:]): val}
+                            args = {key[31:]: val}
                             config.set_collectLayer_local(**args)
                         elif key.startswith("FastTracker.CollectLayer.Function."):
-                            args = {functions.lower_case_name(key[34:]): val}
+                            args = {key[34:]: val}
                             config.set_collectLayer_function(**args)
                     else:
-                        config_name = functions.lower_case_name(key[12:].replace("_",""))
-                        functions.log("config_name:%s,key12:%s,key13:%s,val:%s", config_name, key[12:],val)
-                        if config_name == "servicename":
-                            config_name = "service_name"
-                        elif config_name == "tenantcode":
-                            config_name = "tenant_code"
-                        elif config_name == "usercode":
-                            config_name = "user_code"
-                        elif config_name == "serviceversion":
-                            config_name = "service_version"
-                        elif config_name == "debug.level":
-                            config_name = "debug_level"
-                        functions.log("config_name:%s,key12:%s,key13:%s,val:%s", config_name, key[12:], val)
+                        config_name = functions.lower_case_name(key[12:])
+                        functions.log("config_name:%s,key12:%s,val:%s", config_name, key[12:], val)
                         setattr(config, config_name, val)
         except Exception as e:
             functions.log("python探针环境变量读取错误信息：%s", str(e))
