@@ -20,7 +20,8 @@ def lower_case_name(text):
     for index, char in enumerate(text):
         if char.isupper() and index != 0:
             lst.append("_")
-        lst.append(char)
+        if char != ".":
+            lst.append(char)
 
     return "".join(lst).lower()
 
@@ -36,9 +37,10 @@ def log(text, *args, level=1):
     if config.tracker_logging.get("Level"):
         text = text % args
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-        sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(),text))
+        sys.stdout.write("FAST: %s - %s@%s:%s\n" % (timestamp, __file__, sys._getframe().f_lineno, text))
         sys.stdout.flush()
 
+
 def getUri(text):
     if "http://" in text:
         index = text.find("//")
